==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/lt_LT.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Slaptažodis turi būti bent %s simbolių ilgio",
    "Password needs to contain at least one lower and one upper case character." : "Slaptažodyje turi būti bent vienas didžiųjų ir mažųjų raidžių simbolis.",
    "Password needs to contain at least one numeric character." : "Slaptažodyje turi būti bent vienas skaičius.",
    "Password needs to contain at least one special character." : "Slaptažodyje turi būti bent vienas specialus simbolis.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Slaptažodis įeina į 1,000,000 populiariausiai naudojamų slaptažodžių sąrašą. Prašome pasirinkti kitą.",
    "Password policy" : "Slaptažodžio taisyklės",
    "Minimal length" : "Minimalus ilgis",
    "Forbid common passwords" : "Uždrausti paplitusius slaptažodžius",
    "Password need to be at least %s characters long" : "Slaptažodis turi būti bent %s simbolių ilgio",
    "Password need to contain at least one lower case character and one upper case character." : "Slaptažodyje turi būti bent vienas didžiųjų ir mažųjų raidžių simbolis.",
    "Password need to contain at least one numeric character." : "Slaptažodyje turi būti bent vienas skaičius.",
    "Password need to contain at least one special character." : "Slaptažodyje turi būti bent vienas specialus simbolis.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Slaptažodis įeina į 1,000,000 populiariausiai naudojamų slaptažodžių sąrašą. Prašome pasirinkti kitą."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/lt_LT.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Slaptažodis turi būti bent %s simbolių ilgio",
    "Password needs to contain at least one lower and one upper case character." : "Slaptažodyje turi būti bent vienas didžiųjų ir mažųjų raidžių simbolis.",
    "Password needs to contain at least one numeric character." : "Slaptažodyje turi būti bent vienas skaičius.",
    "Password needs to contain at least one special character." : "Slaptažodyje turi būti bent vienas specialus simbolis.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Slaptažodis įeina į 1,000,000 populiariausiai naudojamų slaptažodžių sąrašą. Prašome pasirinkti kitą.",
    "Password policy" : "Slaptažodžio politika",
    "Minimal length" : "Minimalus ilgis",
    "Forbid common passwords" : "Uždrausti paplitusius slaptažodžius",
    "Enforce upper and lower case characters" : "Versti naudoti didžiąsias ir mažąsias raides",
    "Enforce numeric characters" : "Versti naudoti skaitmenų simbolius",
    "Enforce special characters" : "Versti naudoti specialius simbolius",
    "Password need to be at least %s characters long" : "Slaptažodis turi būti bent %s simbolių ilgio",
    "Password need to contain at least one lower case character and one upper case character." : "Slaptažodyje turi būti bent vienas didžiųjų ir mažųjų raidžių simbolis.",
    "Password need to contain at least one numeric character." : "Slaptažodyje turi būti bent vienas skaičius.",
    "Password need to contain at least one special character." : "Slaptažodyje turi būti bent vienas specialus simbolis.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Slaptažodis įeina į 1,000,000 populiariausiai naudojamų slaptažodžių sąrašą. Prašome pasirinkti kitą."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
